package Faker::Provider::en_US::PhoneNumber;

use Bubblegum::Class;

extends 'Faker::Provider::PhoneNumber';

1;

__DATA__

@@ phone_number_data_formats
+##(#)##########
+##(#)##########
0##########
0##########
###-###-####
(###)###-####
1-###-###-####
###.###.####
###-###-####
(###)###-####
1-###-###-####
###.###.####
###-###-####x###
(###)###-####x###
1-###-###-####x###
###.###.####x###
###-###-####x####
(###)###-####x####
1-###-###-####x####
###.###.####x####
###-###-####x#####
(###)###-####x#####
1-###-###-####x#####
###.###.####x#####
